@@ -15,8 +15,9 @@ MD_DIVIDER = "------"
 DUMP_MODE_DEBUG = 0
 DUMP_MODE_DEFAULT = 1
 DUMP_MODE_SILENT = 2
-DUMP_MODE = DUMP_MODE_DEFAULT
+DUMP_MODE = DUMP_MODE_DEBUG
 
+# 导出的类型
 DUMP_TYPE_BLOCK = 1
 DUMP_TYPE_PAGE = 2
 DUMP_TYPE_DB_TABLE = 4
